.. mdinclude:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 2

   readme
   tuners
   selectors
   recommenders
   api_reference
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
